module FontPair
  ##
  # Fetches a copy of the pairs available on FontPair.co locally.
  class Fetcher
    SOURCE_URL = 'https://fontpair.co'.freeze

    def initialize(filename)
      @filename = filename.freeze
    end

    def fetch
      return initialize_pairs unless File::exists?(@filename)
      update_pairs
    end

    private

    def initialize_pairs
      pairs = fetch_pairs
      File::open(@filename, 'w') { |file| file.puts pairs.join("\n") }
    end

    def update_pairs
      pairs = fetch_pairs

      File::open(@filename, 'w+') do |file|
        puts file.readlines
        file.puts pairs.join("\n") unless file.read == pairs
      end
    end

    def fetch_pairs
      request = Net::HTTP.get(URI(SOURCE_URL))
      page = Nokogiri::HTML(request)

      page.css('.fontName').map { |pair| pair.content }
    end
  end
end

